(virtual-broker-docs)=
# Virtual Broker

The virtual broker immitates the functionality of a real broker for the purpose of backtesting. 
The attributes of the broker can be configured using the [configuration methods](autotrader-config-methods) 
of AutoTrader.


```{eval-rst}
.. autoclass:: autotrader.brokers.virtual.broker.Broker
   :members:
   :private-members:
```
